pub struct ZipProjectCommands {
pub setup: Option<ScriptPath>,
pub build: Option<ScriptPath>,
pub run: ScriptPath,
}Expand description
Script paths used by the future setup/build/run phase executor.
Fields
setup: Option<ScriptPath>build: Option<ScriptPath>run: ScriptPathTrait Implementations
Sourceimpl Clone for ZipProjectCommands
impl Clone for ZipProjectCommands
Sourcefn clone(&self) -> ZipProjectCommands
fn clone(&self) -> ZipProjectCommands
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ZipProjectCommands
impl Debug for ZipProjectCommands
Sourceimpl<'de> Deserialize<'de> for ZipProjectCommands
impl<'de> Deserialize<'de> for ZipProjectCommands
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ZipProjectCommands
Sourceimpl JsonSchema for ZipProjectCommands
impl JsonSchema for ZipProjectCommands
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ZipProjectCommands
impl PartialEq for ZipProjectCommands
Sourcefn eq(&self, other: &ZipProjectCommands) -> bool
fn eq(&self, other: &ZipProjectCommands) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ZipProjectCommands
impl Serialize for ZipProjectCommands
impl StructuralPartialEq for ZipProjectCommands