pub struct ZipProjectPhaseLimits {
pub timeout_sec: u64,
pub memory_limit_mb: u64,
pub cpu_limit_millis: u32,
pub disk_limit_mb: u64,
pub network_access: ZipProjectNetworkAccess,
}Expand description
Concrete limits for one execution phase after challenge-owned policy is applied.
Fields
timeout_sec: u64memory_limit_mb: u64cpu_limit_millis: u32disk_limit_mb: u64network_access: ZipProjectNetworkAccessTrait Implementations
Sourceimpl Clone for ZipProjectPhaseLimits
impl Clone for ZipProjectPhaseLimits
Sourcefn clone(&self) -> ZipProjectPhaseLimits
fn clone(&self) -> ZipProjectPhaseLimits
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ZipProjectPhaseLimits
impl Debug for ZipProjectPhaseLimits
Sourceimpl<'de> Deserialize<'de> for ZipProjectPhaseLimits
impl<'de> Deserialize<'de> for ZipProjectPhaseLimits
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ZipProjectPhaseLimits, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ZipProjectPhaseLimits, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ZipProjectPhaseLimits
Sourceimpl JsonSchema for ZipProjectPhaseLimits
impl JsonSchema for ZipProjectPhaseLimits
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ZipProjectPhaseLimits
impl PartialEq for ZipProjectPhaseLimits
Sourcefn eq(&self, other: &ZipProjectPhaseLimits) -> bool
fn eq(&self, other: &ZipProjectPhaseLimits) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ZipProjectPhaseLimits
impl Serialize for ZipProjectPhaseLimits
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ZipProjectPhaseLimits