pub struct ZipProjectResolvedPhase {
pub name: ZipProjectPhaseName,
pub command: ScriptPath,
}Expand description
One executable phase after command paths and phase limits are resolved.
Fields
name: ZipProjectPhaseNamecommand: ScriptPathTrait Implementations
Sourceimpl Clone for ZipProjectResolvedPhase
impl Clone for ZipProjectResolvedPhase
Sourcefn clone(&self) -> ZipProjectResolvedPhase
fn clone(&self) -> ZipProjectResolvedPhase
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ZipProjectResolvedPhase
impl Debug for ZipProjectResolvedPhase
Sourceimpl<'de> Deserialize<'de> for ZipProjectResolvedPhase
impl<'de> Deserialize<'de> for ZipProjectResolvedPhase
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ZipProjectResolvedPhase
Sourceimpl JsonSchema for ZipProjectResolvedPhase
impl JsonSchema for ZipProjectResolvedPhase
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ZipProjectResolvedPhase
impl PartialEq for ZipProjectResolvedPhase
Sourcefn eq(&self, other: &ZipProjectResolvedPhase) -> bool
fn eq(&self, other: &ZipProjectResolvedPhase) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ZipProjectResolvedPhase
impl Serialize for ZipProjectResolvedPhase
impl StructuralPartialEq for ZipProjectResolvedPhase